[![PyPI](https://img.shields.io/pypi/v/zerotk.easyfs.svg?style=flat-square)](https://pypi.python.org/pypi/zerotk.easyfs)
[![Travis](https://img.shields.io/travis/zerotk/easyfs.svg?style=flat-square)](https://travis-ci.org/zerotk/easyfs)
[![Coveralls](https://img.shields.io/coveralls/zerotk/easyfs.svg?style=flat-square)](https://coveralls.io/github/zerotk/easyfs)

# zerotk.easyfs

File system utilities for python.

```python
import zerotk.easyfs
```
